HideBlizzard = LibStub('AceAddon-3.0'):NewAddon('HideBlizzard', 'AceConsole-3.0')

local defaults = {
	profile = {
		modules = {
			ActionBar = false,
			Buttons = false,
			Party = false,
			Pet = false,
			Player = false,
			SpecialFrames = false,
			Target = false,
		}
	}
}

function HideBlizzard:OnInitialize()
	self.db = LibStub('AceDB-3.0'):New('HideBlizzardDB', defaults)

	do
		local timer, t = nil, 0
		local function update()
			t = t + arg1
			if t > 0.5 then
				timer:SetScript('OnUpdate', nil)
				HideBlizzard:UpdateConfig()
				collectgarbage()
			end
		end
		function HideBlizzard:SetUpdateConfig()
			t = 0
			timer = timer or CreateFrame('Frame', nil, UIParent)
			timer:SetScript('OnUpdate', update)
		end
	end

	function HideBlizzard:UpdateConfig()
		for k, v in self:IterateModules() do
			if v:IsEnabled() then
				v:Disable()
				v:Enable()
			end
		end
	end
end

function HideBlizzard:CheckVersion()
	if self.db.profile.Version ~= GetAddOnMetadata('HideBlizzard', 'Version') then
		if not self.db.profile.Welcome and not self.db.profile.Version then
			return
		else
			self.db.profile.Version = GetAddOnMetadata('HideBlizzard', 'Version')
			self:Print(format('Updated to version %s', self.db.profile.Version))
		end
	end
end

function HideBlizzard:OnEnable()
	self:RegisterCommands()
	self:CheckVersion()

	if self.db.profile.welcome then
		self:Print('An old version of HideBlizzard has been detected. You will need to ReloadUI for HideBlizzard to function properly.')
		UIErrorsFrame:AddMessage('An old version of HideBlizzard has been detected.', .11, .56, 1, 1, 6)
		UIErrorsFrame:AddMessage('You will need to ReloadUI for HideBlizzard to function properly.', .11, .56, 1, 1, 6)
		HideBlizzardDB = nil
	end

	if not self.db.profile.Welcome and not self.db.profile.welcome then
		HideBlizzard:WelcomeDialog()
		self.db.profile.Welcome = true
		self.db.profile.Version = GetAddOnMetadata('HideBlizzard', 'Version')
	end

	for k, v in self:IterateModules() do
		if self.db.profile.modules[k] ~= false then
			v:Enable()
		end
	end

	self.db.RegisterCallback(self, 'OnProfileChanged', 'SetUpdateConfig')
	self.db.RegisterCallback(self, 'OnProfileCopied', 'SetUpdateConfig')
	self.db.RegisterCallback(self, 'OnProfileReset', 'SetUpdateConfig')
end

function HideBlizzard:OnDisable()
end