local mod = HideBlizzard:NewModule('Party', 'AceEvent-3.0')
mod.modName = 'Party'

local options = {
	party = {
		type = 'toggle',
		name = 'Party',
		desc = 'Hide the standard party frames.',
		get = function() return mod.db.profile.party end,
		set = function(info, v)
			mod.db.profile.party = v
			if v then
				mod:EnableParty()
			else
				mod:DisableParty()
			end
		end,
		disabled = function() return not HideBlizzard.db.profile.modules.Party end,
	},
}

local defaults = {
	profile = {
		party = false,
	}
}

function mod:OnInitialize()
	self.db = HideBlizzard.db:RegisterNamespace('Party', defaults)
end

function mod:OnEnable()
	self:UpdateFrames()
end

function mod:OnDisable()
	self:DisableParty()
end

function mod:UpdateFrames()
	if mod.db.profile.party == true then
		self:EnableParty()
	else
		self:DisableParty()
	end
end

function mod:EnableParty()
	for i = 1, MAX_PARTY_MEMBERS do
		local party = _G['PartyMemberFrame'..i]
		party:UnregisterAllEvents()
		party:Hide()
		party.Show = function() end
	end
	UIParent:UnregisterEvent('RAID_ROSTER_UPDATE')
end

function mod:DisableParty()
	for i = 1, MAX_PARTY_MEMBERS do
		local party = _G['PartyMemberFrame'..i]
		party.Show = nil
		party:RegisterEvent('PARTY_MEMBERS_CHANGED')
		party:RegisterEvent('PARTY_LEADER_CHANGED')
		party:RegisterEvent('PARTY_MEMBER_ENABLE')
		party:RegisterEvent('PARTY_MEMBER_DISABLE')
		party:RegisterEvent('PARTY_LOOT_METHOD_CHANGED')
		party:RegisterEvent('MUTELIST_UPDATE')
		party:RegisterEvent('IGNORELIST_UPDATE')
		party:RegisterEvent('UNIT_PVP_UPDATE')
		party:RegisterEvent('UNIT_AURA')
		party:RegisterEvent('UNIT_PET')
		party:RegisterEvent('VARIABLES_LOADED')
		party:RegisterEvent('UNIT_NAME_UPDATE')
		party:RegisterEvent('UNIT_PORTRAIT_UPDATE')
		party:RegisterEvent('UNIT_DISPLAYPOWER')
		party:RegisterEvent('UNIT_ENTERED_VEHICLE')
		party:RegisterEvent('UNIT_EXITED_VEHICLE')
		party:RegisterEvent('VOICE_START')
		party:RegisterEvent('VOICE_STOP')
		party:RegisterEvent('VOICE_STATUS_UPDATE')
		party:RegisterEvent('READY_CHECK')
		party:RegisterEvent('READY_CHECK_CONFIRM')
		party:RegisterEvent('READY_CHECK_FINISHED')
		UnitFrame_OnEvent('PARTY_MEMBERS_CHANGED')
	end
	UIParent:RegisterEvent('RAID_ROSTER_UPDATE')
end

function mod:Info()
	return 'Hides frames connected to party frame.'
end

function mod:GetOptions()
	return options
end