local options = {
	type = 'group',
	args = {
		main = {
			type = 'group',
			name = 'HideBlizzard',
			args = {
				intro = {
					type = 'description',
					order = 1,
					name = 'HideBlizzard lets you hide blizzard frames located on the interface. You can toggle any of the available frames listed to hide them or to show again. The settings are saved per-character so you can have individual settings for each of them.',
				},
				help = {
					type = 'execute',
					order = 2,
					name = 'Open the help dialog',
					func = function()
						HideBlizzard:HelpDialog()
					end,
				},
			}
		},
		modules = {
			type = 'group',
			name = 'Modules',
			desc = 'Modules',
			args = {}
		}
	}
}

function HideBlizzard:RegisterOptions()
	self.optionFrames = {}
	LibStub('AceConfigRegistry-3.0'):RegisterOptionsTable('HideBlizzard', options)
	LibStub('AceConfigRegistry-3.0'):RegisterOptionsTable('HideBlizzardModules', options.args.modules)
	self.optionFrames.HideBlizzard = LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzard', nil, nil, 'main')
	if not options.args.Profiles then
		options.args.Profiles = LibStub('AceDBOptions-3.0'):GetOptionsTable(self.db)
		self.optionFrames.Profiles = LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzard', 'Profiles', 'HideBlizzard', 'Profiles')
	end

	for k, v in self:IterateModules() do
		options.args.modules.args[k:gsub(' ', '_')] = {
			type = 'group',
			name = (v.modName or k),
			args = nil
		}
		local t
		if v.GetOptions then
			t = v:GetOptions()
			t.settingsHeader = {
				type = 'header',
				name = 'Settings',
				order = 12
			}
		end
		t = t or {}
		t.toggle = {
			type = 'toggle', 
			name = v.toggleLabel or ('Enable '..(v.modName or k)), 
			desc = v.Info and v:Info() or ('Enable '..(v.modName or k)), 
			order = 11,
			get = function()
				return HideBlizzard.db.profile.modules[k] ~= false or false
			end,
			set = function(info, v)
				HideBlizzard.db.profile.modules[k] = v
				if v then
					HideBlizzard:EnableModule(k)
				else
					HideBlizzard:DisableModule(k)
				end
			end
		}
		t.header = {
			type = 'header',
			name = v.modName or k,
			order = 9
		}
		if v.Info then
			t.description = {
				type = 'description',
				name = v:Info() .. '\n\n',
				order = 10
			}
		end
		options.args.modules.args[k:gsub(' ', '_')].args = t
	end

	local moduleList = {}
	local moduleNames = {}
	for k, v in pairs(options.args.modules.args) do
		moduleList[v.name] = k
		tinsert(moduleNames, v.name)
	end
	table.sort(moduleNames)
	for _, name in ipairs(moduleNames) do
		LibStub('AceConfigDialog-3.0'):AddToBlizOptions('HideBlizzardModules', name, 'HideBlizzard', moduleList[name])
	end
end